# -*- coding: utf-8 -*-
#
# michael a.g. aïvázis <michael.aivazis@para-sim.com>
# (c) 1998-2024 all rights reserved


# exceptions
from ..framework.exceptions import FrameworkError


class SchemaError(FrameworkError):
    """
    Base class for all errors generated by this package
    """


class CastingError(SchemaError):
    """
    Exception raised on failed attempts to convert a value to one of the supported types
    """

    # meta-methods
    def __init__(self, value, **kwds):
        # chain up
        super().__init__(**kwds)
        # save the error info
        self.value = value
        # all done
        return


class EnumError(SchemaError):
    """
    Exception raised on failed attempts to convert an enum value to its actual type
    """

    # the complaint
    description = "could not coerce {0.value!r} into an enum of type {0.enum!r}"

    # meta-methods
    def __init__(self, enum, value, error, **kwds):
        # chain up
        super().__init__(**kwds)
        # save the error info
        self.enum = enum
        self.value = value
        self.error = error
        # all done
        return


# end of file
